# User Guide

!!! note "Backwards Compatibility and Deprecations"

    Octopus is in a constant state of development. As part of this, interfaces and objects
    might change in ways breaking existing code. We aspire to provide backwards **support
    for deprecated code of the last three minor versions**. After this time, old code will
    generally be removed. Both the moment of deprecation and full removal (deprecation
    expiration) will be noted in the [changelog](../changelog.md).

The most commonly used interface Octopus provides is the central
[`OctoStudy`](../reference/study.md) object.

Detailed examples of how to use individual API components can be found via the links below:

* [Classification](classification.md)
* [Regression](regression.md)
* [Time to Event](time_to_event.md)
